summaryrefslogtreecommitdiffstats
path: root/tests/auto/gui/painting
diff options
context:
space:
mode:
authorGiuseppe D'Angelo <giuseppe.dangelo@kdab.com>2024-03-01 19:15:06 +0100
committerGiuseppe D'Angelo <giuseppe.dangelo@kdab.com>2024-04-04 16:08:22 +0100
commit7f72a93e874f5e52612983ad3b764f07216bf62e (patch)
tree957a24c97e355f2f9e5c0369898acaa981bdf39b /tests/auto/gui/painting
parentadb49d65e0774fa6be0b0d9d490c6f1fc5066a1b (diff)
Port QImage::Format_CMYK32 to CMYK8888
Follow the established convention that byte-oriented image formats have the "8888" suffix, not "32". The old enum name is temporarily left to help port other submodules. This work has been kindly sponsored by the QGIS project (https://qgis.org/). Change-Id: I4b6f10cb22312b614cb9cf4b0ac439907276c538 Reviewed-by: Allan Sandfeld Jensen <allan.jensen@qt.io>
Diffstat (limited to 'tests/auto/gui/painting')
-rw-r--r--tests/auto/gui/painting/qpainter/tst_qpainter.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/tests/auto/gui/painting/qpainter/tst_qpainter.cpp b/tests/auto/gui/painting/qpainter/tst_qpainter.cpp
index 96f92105d1..92b28f65bd 100644
--- a/tests/auto/gui/painting/qpainter/tst_qpainter.cpp
+++ b/tests/auto/gui/painting/qpainter/tst_qpainter.cpp
@@ -2784,7 +2784,7 @@ void tst_QPainter::monoImages()
for (int i = 1; i < QImage::NImageFormats; ++i) {
for (int j = 0; j < numColorPairs; ++j) {
const QImage::Format format = QImage::Format(i);
- if (format == QImage::Format_Indexed8 || format == QImage::Format_CMYK32)
+ if (format == QImage::Format_Indexed8 || format == QImage::Format_CMYK8888)
continue;
QImage img(2, 2, format);
@@ -3554,9 +3554,9 @@ void tst_QPainter::drawImage_data()
for (int srcFormat = QImage::Format_Mono; srcFormat < QImage::NImageFormats; ++srcFormat) {
for (int dstFormat = QImage::Format_Mono; dstFormat < QImage::NImageFormats; ++dstFormat) {
// Indexed8 and CMYK32 can't be painted to, and Alpha8 can't hold a color.
if (dstFormat == QImage::Format_Indexed8 ||
- dstFormat == QImage::Format_CMYK32 ||
+ dstFormat == QImage::Format_CMYK8888 ||
dstFormat == QImage::Format_Alpha8) {
continue;
}
@@ -3554,9 +3554,9 @@ void tst_QPainter::drawImage_data()
for (int srcFormat = QImage::Format_Mono; srcFormat < QImage::NImageFormats; ++srcFormat) {
for (int dstFormat = QImage::Format_Mono; dstFormat < QImage::NImageFormats; ++dstFormat) {
- // Indexed8 and CMYK32 can't be painted to, and Alpha8 can't hold a color.
+ // Indexed8 and CMYK8888 can't be painted to, and Alpha8 can't hold a color.
if (dstFormat == QImage::Format_Indexed8 ||